@@ -1,6 +1,6 @@
 #############################################################################
 #
-# Copyright (c) 2006-2007 Zope Corporation and Contributors.
+# Copyright (c) 2006-2007 Zope Foundation and Contributors.
 # All Rights Reserved.
 #
 # This software is subject to the provisions of the Zope Public License,
@@ -22,7 +22,6 @@ from martian import util
 
 import grokcore.annotation
 
-
 def default_annotation_provides(factory, module, **data):
     base_interfaces = interface.implementedBy(grokcore.annotation.Annotation)
     factory_interfaces = interface.implementedBy(factory)
@@ -63,7 +62,7 @@ class AnnotationGrokker(martian.ClassGrokker):
 
         config.action(
             discriminator=('adapter', adapter_context, provides, ''),
-            callable=component.provideAdapter,
+            callable=grokcore.component.provideAdapter,
             args=(getAnnotation,),
             )
         return True
